package com.ruoyi.rocketmq.mapper;

import com.ruoyi.rocketmq.domain.InitialSwitchInfo;
import org.springframework.data.repository.query.Param;

import java.util.List;

/**
 * 交换机流量监控信息Mapper接口
 * 
 * @author gyt
 * @date 2025-08-25
 */
public interface InitialSwitchInfoMapper 
{
    /**
     * 查询交换机流量监控信息
     *
     * @param id 交换机流量监控信息主键
     * @return 交换机流量监控信息
     */
    public InitialSwitchInfo selectInitialSwitchInfoById(Long id);

    /**
     * 查询交换机流量监控信息列表
     *
     * @param initialSwitchInfo 交换机流量监控信息
     * @return 交换机流量监控信息集合
     */
    public List<InitialSwitchInfo> selectInitialSwitchInfoList(InitialSwitchInfo initialSwitchInfo);

    /**
     * 新增交换机流量监控信息
     *
     * @param initialSwitchInfo 交换机流量监控信息
     * @return 结果
     */
    public int insertInitialSwitchInfo(InitialSwitchInfo initialSwitchInfo);

    /**
     * 修改交换机流量监控信息
     *
     * @param initialSwitchInfo 交换机流量监控信息
     * @return 结果
     */
    public int updateInitialSwitchInfo(InitialSwitchInfo initialSwitchInfo);

    /**
     * 删除交换机流量监控信息
     *
     * @param id 交换机流量监控信息主键
     * @return 结果
     */
    public int deleteInitialSwitchInfoById(Long id);

    /**
     * 批量删除交换机流量监控信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInitialSwitchInfoByIds(Long[] ids);

    /**
     * 批量新增交换机流量监控信息
     *
     * @param list 交换机流量监控信息集合
     * @return 结果
     */
    public int batchInsertInitialSwitchInfo(@Param("list") List<InitialSwitchInfo> list);

    InitialSwitchInfo getSwitchNetDetailsMsg(InitialSwitchInfo initialSwitchInfo);
}
